==> kmud-0.5.tar.gz: kmud-0.5/kmud/dialogs/dlgmaproomdescription.cpp <==
/***************************************************************************
                          dlgmaproomdescription.cpp  -  description
                             -------------------
    begin                : Fri Sep 22 2000
    copyright            : (C) 2000 by John-Paul Stanford
    email                : john-paul.stanford@virgin.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dlgmaproomdescription.h"

DlgMapRoomDescription::DlgMapRoomDescription(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

DlgMapRoomDescription::~DlgMapRoomDescription(){
}

void DlgMapRoomDescription::setDescription(QString str){
	txtLong->setText(str);
}

QString DlgMapRoomDescription::getDescription(void){
	return txtLong->text();
}

void DlgMapRoomDescription::setLabel(QString str){
	txtShort->setText(str);
}

QString DlgMapRoomDescription::getLabel(void){
	return txtShort->text();
}

==> kmud-1.0.tar.gz: kmud-1.0/kmud/dialogs/dlgmaproomdescription.cpp <==
/***************************************************************************
                          dlgmaproomdescription.cpp  -  description
                             -------------------
    begin                : Fri Sep 22 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "dlgmaproomdescription.h"

DlgMapRoomDescription::DlgMapRoomDescription(QWidget *parent, const char *name) : QDialog(parent,name,true){
	initDialog();
}

DlgMapRoomDescription::~DlgMapRoomDescription(){
}

void DlgMapRoomDescription::setDescription(QString str){
	txtLong->setText(str);
}

QString DlgMapRoomDescription::getDescription(void){
	return txtLong->text();
}

void DlgMapRoomDescription::setLabel(QString str){
	txtShort->setText(str);
}

QString DlgMapRoomDescription::getLabel(void){
	return txtShort->text();
}
